[vlc-commits] commit: skins2: translate $F into local path instead of uri when possible ( Erwan Tulou )

git at videolan.org git at videolan.org
Sat Jul 31 18:05:43 CEST 2010


vlc | branch: master | Erwan Tulou <erwan10 at videolan.org> | Fri Jul 30 11:24:19 2010 +0200| [6e59bfe80fbbe314625d54ab74a4f7edbb28aef4] | committer: Erwan Tulou 

skins2: translate $F into local path instead of uri when possible

Local paths are more user-friendly for display than full uri
when that makes sense

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=6e59bfe80fbbe314625d54ab74a4f7edbb28aef4
---

 modules/gui/skins2/src/vlcproc.cpp |    8 ++++++--
 1 files changed, 6 insertions(+), 2 deletions(-)

diff --git a/modules/gui/skins2/src/vlcproc.cpp b/modules/gui/skins2/src/vlcproc.cpp
index a0a0e34..13beffa 100644
--- a/modules/gui/skins2/src/vlcproc.cpp
+++ b/modules/gui/skins2/src/vlcproc.cpp
@@ -31,6 +31,7 @@
 #include <vlc_aout.h>
 #include <vlc_vout.h>
 #include <vlc_playlist.h>
+#include <vlc_url.h>
 
 #include "vlcproc.hpp"
 #include "os_factory.hpp"
@@ -476,9 +477,12 @@ void VlcProc::on_item_current_changed( vlc_object_t* p_obj, vlc_value_t newVal )
     SET_TEXT( m_cVarStreamName, UString( getIntf(), psz_name ) );
     free( psz_name );
 
     // Update full uri
     char *psz_uri = input_item_GetURI( p_item );
-    SET_TEXT( m_cVarStreamURI, UString( getIntf(), psz_uri ) );
+    char *psz_path = make_path( psz_uri );
+    char *psz_save = psz_path ? psz_path : psz_uri;
+    SET_TEXT( m_cVarStreamURI, UString( getIntf(), psz_save ) );
+    free( psz_path );
     free( psz_uri );
 
     // Update art uri
@@ -476,9 +477,12 @@ void VlcProc::on_item_current_changed( vlc_object_t* p_obj, vlc_value_t newVal )
     free( psz_name );
 
-    // Update full uri
+    // Update local path (if possible) or full uri
     char *psz_uri = input_item_GetURI( p_item );



More information about the vlc-commits mailing list